@@ -7,7 +7,7 @@ Attean::API::Serializer - Serializer role
 
 =head1 VERSION
 
-This document describes Attean::API::Serializer version 0.021
+This document describes Attean::API::Serializer version 0.033
 
 =head1 DESCRIPTION
 
@@ -34,6 +34,12 @@ produced by this serializer.
 Returns a L<Type::Tiny> object representing the type of items that are consumed
 during serialization.
 
+=item C<< file_extensions >>
+
+Returns an ARRAY reference of file extensions commonly associated with the
+media types supported by the serializer (and returned by C<< media_types >>).
+File extensions should NOT include a leading dot.
+
 =item C<< serialize_iter_to_io( $fh, $iterator ) >>
 
 Serializes the elements from the L<Attean::API::Iterator> C<< $iterator >> to
@@ -68,14 +74,15 @@ UTF-8 encoded byte string.
 
 use Type::Tiny;
 
-package Attean::API::Serializer 0.021 {
+package Attean::API::Serializer 0.033 {
 	use Moo::Role;
 	use Carp qw(confess);
 	
 	requires 'canonical_media_type'; # => (is => 'ro', isa => 'Str', init_arg => undef);
 	requires 'media_types'; # => (is => 'ro', isa => 'ArrayRef[Str]', init_arg => undef);
 	requires 'handled_type'; # => (is => 'ro', isa => 'Type::Tiny', init_arg => undef);
-	
+	requires 'file_extensions'; # => (is => 'ro', isa => 'ArrayRef[Str]', init_arg => undef);
+
 	requires 'serialize_iter_to_io';		# serialize_iter_to_io($io, $iter)
 	requires 'serialize_iter_to_bytes';		# $data = serialize_iter_to_bytes($iter)
 
@@ -103,27 +110,31 @@ package Attean::API::Serializer 0.021 {
 		my $iter	= Attean::ListIterator->new( values => [@_], item_type => $self->handled_type->role );
 		return $self->serialize_iter_to_bytes($iter);
 	}
+	
+	sub file_extensions { return [] }
 }
 
-package Attean::API::AbbreviatingSerializer 0.021 {
+package Attean::API::AbbreviatingSerializer 0.033 {
 	# Serializer that can make use of a base IRI and/or prefix IRI mappings
-	use Types::Standard qw(InstanceOf ConsumerOf Maybe);
+	use Types::Standard qw(InstanceOf ConsumerOf Maybe Bool);
+	use Types::Namespace qw( NamespaceMap );
 
 	use Moo::Role;
 
 	with 'Attean::API::Serializer';
 
 	has base		=> (is => 'ro', isa => ConsumerOf['Attean::API::IRI'], predicate => 'has_base');
-	has namespaces	=> (is => 'ro', isa => Maybe[InstanceOf['URI::NamespaceMap']], predicate => 'has_namespaces');
+	has namespaces	=> (is => 'ro', isa => Maybe[NamespaceMap], predicate => 'has_namespaces');
+	has omit_base => (is => 'ro', isa => Bool, default => 0);
 }
 
-package Attean::API::AppendableSerializer 0.021 {
+package Attean::API::AppendableSerializer 0.033 {
 	# Serializer for a format that allows multiple serialization calls to be appended and remain syntactically valid
 	use Moo::Role;
 	with 'Attean::API::Serializer';
 }
 
-package Attean::API::TermSerializer 0.021 {
+package Attean::API::TermSerializer 0.033 {
 	use Moo::Role;
 	with 'Attean::API::Serializer';
 	sub handled_type {
@@ -132,7 +143,7 @@ package Attean::API::TermSerializer 0.021 {
 	}
 }
 
-package Attean::API::TripleSerializer 0.021 {
+package Attean::API::TripleSerializer 0.033 {
 	use Moo::Role;
 	with 'Attean::API::Serializer';
 	sub handled_type {
@@ -141,7 +152,7 @@ package Attean::API::TripleSerializer 0.021 {
 	}
 }
 
-package Attean::API::QuadSerializer 0.021 {
+package Attean::API::QuadSerializer 0.033 {
 	use Moo::Role;
 	with 'Attean::API::Serializer';
 	
@@ -151,7 +162,7 @@ package Attean::API::QuadSerializer 0.021 {
 	}
 }
 
-package Attean::API::MixedStatementSerializer 0.021 {
+package Attean::API::MixedStatementSerializer 0.033 {
 	use Moo::Role;
 	with 'Attean::API::Serializer';
 	
@@ -161,7 +172,7 @@ package Attean::API::MixedStatementSerializer 0.021 {
 	}
 }
 
-package Attean::API::ResultSerializer 0.021 {
+package Attean::API::ResultSerializer 0.033 {
 	use Moo::Role;
 	with 'Attean::API::Serializer';
 	sub handled_type {
@@ -177,8 +188,9 @@ package Attean::API::ResultSerializer 0.021 {
 		if (scalar(@_)) {
 			@vars	= $_[0]->variables;
 		}
+		
 		my $iter	= Attean::ListIterator->new( values => [@_], item_type => $self->handled_type->role, variables => \@vars );
-		return $self->serialize_list_to_io($io, $iter);
+		return $self->serialize_iter_to_io($io, $iter);
 	};
 	
 	around 'serialize_list_to_bytes' => sub {
@@ -212,7 +224,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2018 Gregory Todd Williams.
+Copyright (c) 2014--2022 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
