@@ -4,7 +4,7 @@ AtteanX::Serializer::SPARQL - SPARQL Serializer
 
 =head1 VERSION
 
-This document describes AtteanX::Serializer::SPARQL version 0.021
+This document describes AtteanX::Serializer::SPARQL version 0.033
 
 =head1 SYNOPSIS
 
@@ -39,7 +39,7 @@ This document describes AtteanX::Serializer::SPARQL version 0.021
 use v5.14;
 use warnings;
 
-package AtteanX::Serializer::SPARQL 0.021 {
+package AtteanX::Serializer::SPARQL 0.033 {
 	use Moo;
 	use Data::Dumper;
 	use Encode qw(encode);
@@ -55,14 +55,20 @@ package AtteanX::Serializer::SPARQL 0.021 {
 	sub media_types {
 		return [qw(application/sparql-query)];
 	}
+
+=item C<< file_extensions >>
+
+Returns a list of file extensions associated with the serialized format.
+
+=cut
+
+	sub file_extensions { return [qw(rq ru)] };
 	
 	sub handled_type {
 		state $ITEM_TYPE = Type::Tiny::Role->new(role => 'AtteanX::SPARQL::Token');
 		return $ITEM_TYPE;
 	}
 
-	sub file_extensions { return [qw(rq)] }
-
 =item C<< serialize_iter_to_io( $fh, $iterator ) >>
 
 Serializes the SPARQL token objects from C<< $iterator >> to the
@@ -281,7 +287,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2018 Gregory Todd Williams. This
+Copyright (c) 2014--2022 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
